==> eleventy-0.8.0-beta.1.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.8.0-beta.1

| Filename                                                   | % Lines | % Statements | % Functions | % Branches |
| ---------------------------------------------------------- | ------- | ------------ | ----------- | ---------- |
| `total`                                                    | 88.09%  | 88.16%       | 87.56%      | 80.31%     |
| `config.js`                                                | 100%    | 100%         | 100%        | 100%       |
| `src/Benchmark.js`                                         | 91.67%  | 91.67%       | 83.33%      | 66.67%     |
| `src/BenchmarkGroup.js`                                    | 67.65%  | 67.65%       | 71.43%      | 30%        |
| `src/BenchmarkManager.js`                                  | 76.47%  | 76.47%       | 71.43%      | 75%        |
| `src/Config.js`                                            | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`                                          | 54.29%  | 54.29%       | 57.58%      | 46.15%     |
| `src/EleventyBaseError.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyCommandCheck.js`                              | 100%    | 100%         | 100%        | 87.5%      |
| `src/EleventyConfig.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyErrorHandler.js`                              | 85.19%  | 85.19%       | 83.33%      | 64%        |
| `src/EleventyErrorUtil.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyExtensionMap.js`                              | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyFiles.js`                                     | 94.31%  | 94.31%       | 88.89%      | 90.48%     |
| `src/EleventyServe.js`                                     | 36.07%  | 36.07%       | 56.25%      | 24.39%     |
| `src/EleventyWatchTargets.js`                              | 93.48%  | 93.48%       | 90%         | 93.33%     |
| `src/Template.js`                                          | 92.99%  | 93.04%       | 97.83%      | 84.16%     |
| `src/TemplateCache.js`                                     | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateCollection.js`                                | 93.1%   | 93.55%       | 92.31%      | 80%        |
| `src/TemplateConfig.js`                                    | 90.91%  | 90.91%       | 66.67%      | 90%        |
| `src/TemplateContent.js`                                   | 94.2%   | 94.2%        | 100%        | 90%        |
| `src/TemplateData.js`                                      | 94.3%   | 94.38%       | 100%        | 81.25%     |
| `src/TemplateFileSlug.js`                                  | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateGlob.js`                                      | 93.33%  | 93.33%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateLayoutPathResolver.js`                        | 95.74%  | 95.74%       | 100%        | 88.89%     |
| `src/TemplateMap.js`                                       | 97.74%  | 97.74%       | 100%        | 93.83%     |
| `src/TemplatePassthrough.js`                               | 76.92%  | 76.92%       | 75%         | 0%         |
| `src/TemplatePassthroughManager.js`                        | 81.48%  | 81.48%       | 81.25%      | 75%        |
| `src/TemplatePath.js`                                      | 100%    | 100%         | 95.65%      | 100%       |
| `src/TemplatePermalink.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/TemplatePermalinkNoWrite.js`                          | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`                                    | 98.7%   | 98.7%        | 100%        | 95.24%     |
| `src/TemplateWriter.js`                                    | 86.21%  | 86.21%       | 75%         | 37.5%      |
| `src/UserConfig.js`                                        | 64.42%  | 64.63%       | 52.27%      | 53.97%     |
| `src/Engines/Ejs.js`                                       | 94.74%  | 94.74%       | 85.71%      | 66.67%     |
| `src/Engines/Haml.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`                                | 100%    | 100%         | 100%        | 83.33%     |
| `src/Engines/Html.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScript.js`                                | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScriptTemplateLiteral.js`                 | 94.44%  | 94.44%       | 100%        | 100%       |
| `src/Engines/Liquid.js`                                    | 95.65%  | 95.65%       | 96.15%      | 80%        |
| `src/Engines/Markdown.js`                                  | 89.29%  | 89.29%       | 87.5%       | 75%        |
| `src/Engines/Mustache.js`                                  | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`                                  | 93.55%  | 93.55%       | 100%        | 87.5%      |
| `src/Engines/Pug.js`                                       | 100%    | 100%         | 100%        | 75%        |
| `src/Engines/TemplateEngine.js`                            | 100%    | 100%         | 100%        | 100%       |
| `src/Errors/TemplateContentPrematureUseError.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Errors/UsingCircularTemplateContentReferenceError.js` | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Slug.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Url.js`                                       | 100%    | 100%         | 100%        | 100%       |
| `src/Plugins/Pagination.js`                                | 92.38%  | 92.52%       | 93.75%      | 81.25%     |
| `src/Util/Capitalize.js`                                   | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Merge.js`                                        | 92.86%  | 92.86%       | 100%        | 86.36%     |
| `src/Util/Pluralize.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`                                     | 84.78%  | 85.11%       | 73.91%      | 94.44%     |

==> eleventy-0.9.0-beta.1.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.9.0-beta.1

| Filename                                                   | % Lines | % Statements | % Functions | % Branches |
| ---------------------------------------------------------- | ------- | ------------ | ----------- | ---------- |
| `total`                                                    | 88.61%  | 88.67%       | 87.37%      | 81.13%     |
| `config.js`                                                | 100%    | 100%         | 100%        | 100%       |
| `src/Benchmark.js`                                         | 91.67%  | 91.67%       | 83.33%      | 66.67%     |
| `src/BenchmarkGroup.js`                                    | 67.65%  | 67.65%       | 71.43%      | 30%        |
| `src/BenchmarkManager.js`                                  | 76.47%  | 76.47%       | 71.43%      | 75%        |
| `src/Config.js`                                            | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`                                          | 54.29%  | 54.29%       | 57.58%      | 46.15%     |
| `src/EleventyBaseError.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyCommandCheck.js`                              | 100%    | 100%         | 100%        | 87.5%      |
| `src/EleventyConfig.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyErrorHandler.js`                              | 91.67%  | 91.67%       | 100%        | 67.57%     |
| `src/EleventyErrorUtil.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyExtensionMap.js`                              | 96.67%  | 96.67%       | 92%         | 100%       |
| `src/EleventyFiles.js`                                     | 94.44%  | 94.44%       | 89.19%      | 91.3%      |
| `src/EleventyServe.js`                                     | 36.07%  | 36.07%       | 56.25%      | 24.39%     |
| `src/EleventyWatchTargets.js`                              | 93.48%  | 93.48%       | 90%         | 93.33%     |
| `src/Template.js`                                          | 94.68%  | 94.72%       | 97.87%      | 86.14%     |
| `src/TemplateCache.js`                                     | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateCollection.js`                                | 93.1%   | 93.55%       | 92.31%      | 80%        |
| `src/TemplateConfig.js`                                    | 91.23%  | 91.23%       | 66.67%      | 91.67%     |
| `src/TemplateContent.js`                                   | 93.83%  | 93.83%       | 94.12%      | 91.18%     |
| `src/TemplateData.js`                                      | 94.41%  | 94.48%       | 100%        | 82%        |
| `src/TemplateFileSlug.js`                                  | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateGlob.js`                                      | 93.33%  | 93.33%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateLayoutPathResolver.js`                        | 95.74%  | 95.74%       | 100%        | 88.89%     |
| `src/TemplateMap.js`                                       | 97.48%  | 97.48%       | 93.94%      | 90.24%     |
| `src/TemplatePassthrough.js`                               | 94.44%  | 94.44%       | 88.89%      | 80%        |
| `src/TemplatePassthroughManager.js`                        | 91.38%  | 91.38%       | 100%        | 71.43%     |
| `src/TemplatePath.js`                                      | 100%    | 100%         | 95.65%      | 100%       |
| `src/TemplatePermalink.js`                                 | 100%    | 100%         | 100%        | 100%       |
| `src/TemplatePermalinkNoWrite.js`                          | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`                                    | 98.7%   | 98.7%        | 100%        | 95.24%     |
| `src/TemplateWriter.js`                                    | 81.25%  | 81.25%       | 71.43%      | 30%        |
| `src/UserConfig.js`                                        | 64.46%  | 64.67%       | 51.11%      | 54.55%     |
| `src/Engines/Ejs.js`                                       | 95%     | 95%          | 85.71%      | 88.89%     |
| `src/Engines/Haml.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`                                | 100%    | 100%         | 100%        | 83.33%     |
| `src/Engines/Html.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScript.js`                                | 96%     | 96.08%       | 100%        | 88.1%      |
| `src/Engines/JavaScriptTemplateLiteral.js`                 | 94.44%  | 94.44%       | 100%        | 100%       |
| `src/Engines/Liquid.js`                                    | 95.89%  | 95.89%       | 96.15%      | 86.67%     |
| `src/Engines/Markdown.js`                                  | 90.91%  | 90.91%       | 88.89%      | 81.25%     |
| `src/Engines/Mustache.js`                                  | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`                                  | 88.52%  | 88.52%       | 94.74%      | 84.62%     |
| `src/Engines/Pug.js`                                       | 100%    | 100%         | 100%        | 88.89%     |
| `src/Engines/TemplateEngine.js`                            | 100%    | 100%         | 100%        | 100%       |
| `src/Errors/TemplateContentPrematureUseError.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Errors/UsingCircularTemplateContentReferenceError.js` | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Slug.js`                                      | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Url.js`                                       | 100%    | 100%         | 100%        | 100%       |
| `src/Plugins/Pagination.js`                                | 92.38%  | 92.52%       | 93.75%      | 81.25%     |
| `src/Util/Capitalize.js`                                   | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Merge.js`                                        | 92.86%  | 92.86%       | 100%        | 86.36%     |
| `src/Util/Pluralize.js`                                    | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`                                     | 84.78%  | 85.11%       | 73.91%      | 94.44%     |
